#
# spec file for package melody
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           melody
Version:        2.2.1
Release:        1.20
Summary:        A music player for local files and remote streams
License:        GPL-3.0-or-later
Group:          Productivity/Multimedia/Sound/Players
URL:            https://artemanufrij.github.io
Source:         https://github.com/artemanufrij/playmymusic/archive/%{version}.tar.gz#/playmymusic-%{version}.tar.gz
BuildRequires:  fdupes
BuildRequires:  gettext-runtime >= 0.19.7
BuildRequires:  hicolor-icon-theme
BuildRequires:  meson >= 0.40.0
BuildRequires:  pkgconfig
BuildRequires:  update-desktop-files
BuildRequires:  vala >= 0.42.0
BuildRequires:  pkgconfig(granite)
BuildRequires:  pkgconfig(gstreamer-audio-1.0)
BuildRequires:  pkgconfig(gstreamer-pbutils-1.0)
BuildRequires:  pkgconfig(gstreamer-tag-1.0)
BuildRequires:  pkgconfig(gtk+-3.0)
BuildRequires:  pkgconfig(json-glib-1.0)
BuildRequires:  pkgconfig(libsoup-2.4)
BuildRequires:  pkgconfig(sqlite3)
BuildRequires:  pkgconfig(taglib_c)
Recommends:     %{name}-lang

%description
A music player for listening local music files, online radios and Audio CDs.

%lang_package

%prep
%setup -q -n playmymusic-%{version}

cp --no-preserve='mode' debian/copyright COPYING

%build
%meson
%meson_build

%install
%meson_install
%find_lang com.github.artemanufrij.playmymusic %{name}.lang
%fdupes %{buildroot}/%{_datadir}

%files
%license COPYING
%doc README.md
%{_bindir}/com.github.artemanufrij.playmymusic
%{_datadir}/applications/com.github.artemanufrij.playmymusic.desktop
%{_datadir}/glib-2.0/schemas/com.github.artemanufrij.playmymusic.gschema.xml
%{_datadir}/icons/hicolor/*/apps/com.github.artemanufrij.playmymusic*.??g
%{_datadir}/icons/hicolor/*/apps/playlist-queue-symbolic.??g
%{_datadir}/icons/hicolor/*/apps/playlist-symbolic.??g
%{_datadir}/metainfo/com.github.artemanufrij.playmymusic.appdata.xml

%files lang -f %{name}.lang

%changelog
* Mon Jul 22 2019 Alexei Podvalsky <avvissu@yandex.by>
- Update to 2.2.1:
  * Merge pull request #158 from artemanufrij/sleep-on-async-scan
  * Make post_install.py script executable
  * Update packaging for meson
  * Fix … typo
  * Add tooltips
  * Fix appstream
  * Let LocalFilesManager handle file paths while importing
    playlist
  * Fix playlist import on relative paths and symlinks
  * just a comment
* Mon Nov 19 2018 Alexei Podvalsky <avvissu@yandex.by>
- Update to 2.2.0:
  * file name for queue export
  * po/pot content; tooltip
  * added import button into status bar
  * import playlist
  * Radio: Fix new Radio Popup
  * markup for playlist details
  * tracks counter and playlist duration
  * Queue export
  * Export Playlist
  * select button when moved queue into playlist
* Mon Nov  5 2018 Alexei Podvalsky <avvissu@yandex.by>
- Update to 2.1.0:
  * improved smooth playing for mix collections
  * moved State.NULL mode from EOS to next ()
  * update po/pot content; don't sort album view if view mode ==
    1 (default)
  * sorting menu
  * new option: remember track progress
  * add launchable tag
  * add few missing tags to the appdata file
  * update changelog for debian package
  * fix shuffle and repeat tooltip
  * Add a download on Flathub badge
  * Update README.md
  * radio icon
  * Merge pull request #151 from kaisfm/master
  * Add preview for choose_new_cover
  * Update zh_CN.po
  * code clean up
  * remove spinner if it's not in use
  * Update ru.po
  * context menu: don't show separator if no playlists are
    available
* Mon Oct 29 2018 Alexei Podvalsky <avvissu@yandex.by>
- Update to 2.0.0:
  * fixed alert for "no items found" inside playlists
  * removen wapi from meson
  * deleted unuserd vapi stuff
  * updated po/pot content
  * added do_sort method into playlistview
  * remove PlaylistView class. use playlist instead
  * moved from flowbox to box inside playlist
  * ignore shuffle mode for queue
  * PAUSED behavior for queue
  * queue button opacity
  * don't show queue playlist inside context menu
  * new symbolic icons
  * RC: Queue Functionality
  * imporoved context menu
  * set custom playlist title if it was creating fom queue
  * prepare for Queue function
  * adden toast message; protect hidding of all columns
* Mon Oct 22 2018 Alexei Podvalsky <avvissu@yandex.by>
- Update to 1.1.2:
  * Update az.po
  * changed id into appdata
  * fixed restore window size
  * fixed warnings for appdata
  * Traduzione Italiana
  * Add files via upload
  * changed appdata
* Sat Sep  8 2018 Alexei Podvalsky <avvissu@yandex.by>
- Update to 1.1.1:
  * buttons can't grab focus
  * improved grabing focus
  * fix toggle playing in trackview
  * Update README.md
  * tracks view: scroll to current song
  * new option: Remove Playlist if last Track was removed
    [default: true]
  * don't reset timer if playing was paused
  * Add tracks into Playlists directly from TrackView
  * commit edit of radio station by ctrl+enter
  * improved initial load
  * toggle playing by space
  * Update com.github.artemanufrij.playmymusic.appdata.xml.in
* Wed Aug  1 2018 avvissu@yandex.by
- Update to 1.1.0:
  * fixed appdata
  * prepare for new release
- Switch to metainfo from appdata
- Remove obsolete macros
* Fri Jun 29 2018 avvissu@yandex.by
- Update to 1.0.3:
  * Close dialogs "Edit Album Properties" / "Edit Artist
    Properties" by single X click
  * fixed sorting if all tracks are 0
  * Create fr_FR.po
  * fixed search in Tracks View
  * Update ru.po
  * use markdown utils
  * [MB] fixed first behaviour
  * changed size of artist cover
  * remove 'excape'
  * named scan thread
  * show corrupt uri
  * use escaped string
  * Import files into library; Use FileUtils instead File instance
  * updated de.po file
* Sun Jun 10 2018 jengelh@inai.de
- Fix broken sentence in description and update summary.
* Sat Apr  7 2018 avvissu@yandex.by
- Update to 1.0.1:
  * simplify actions
  * use newer gtk functions
  * Change indicator to show CD artist
  * changed meson
  * added oars
  * Update readme
  * switch to meson
  * updated po/pot content
  * Fetching Artist Art; Using FileUtils instead File
  * fixed '&' in tracksView
  * Update com.github.artemanufrij.playmymusic.appdata.xml
* Sat Mar 17 2018 avvissu@yandex.by
- Update to 0.6.7:
  * open right view for audio CD
  * drag line color
  * Update pt_BR.po
  * double click for start playing
* Fri Mar  9 2018 avvissu@yandex.by
- Update to 0.6.5:
  * Merge branch 'master' of github.com:artemanufrij/playmymusic
  * default-decoration
  * Merge pull request #83 from dar5hak/add-gitignore
  * Add~ to .gitignore
  * fix start
  * desktop actins
  * remove help
  * improved .desktop actions behavior
  * back to static quckmenu
  * code style
  * debian
* Fri Mar  2 2018 avvissu@yandex.by
- Initial package
